@@ -819,3 +819,83 @@ get_from_env <- function(sysname) {
 
   return(outlist[outlist != ""])
 }
+
+
+# render quick check tables
+render_difference_checks <- function(dat_table, logfile_dir = NULL) {
+
+  # get the threshold from the environment, if they are not set, use
+  # default values
+
+  high <- Sys.getenv("PERCENT_THRESHOLD_HIGH", unset = 15)
+  low <- Sys.getenv("PERCENT_THRESHOLD_LOW", unset = 5)
+
+  if (low > high) {
+    DIZtools::feedback(
+      print_this = paste0(
+       "Invalid thresholds:
+       PERCENT_THRESHOLD_HIGH is lower than PERCENT_THRESHOLD_LOW. " ,
+       "Using default thresholds.."
+      ),
+      findme = "au9db9dfd34",
+      logfile_dir = logfile_dir
+    )
+    high <- 15
+    low <- 5
+  }
+
+  brks <- c(low, high)
+  clrs <- c("lightgreen", "orange", "red")
+
+
+  out <-
+   DT::datatable(
+     dat_table,
+     options = list(
+       dom = "t",
+       scrollY = "30vh",
+       pageLength = nrow(dat_table)
+     ),
+     rownames = FALSE
+   ) %>%
+   DT::formatStyle(columns = c(2, 3, 4, 5),
+                    backgroundColor = DT::styleInterval(brks, clrs))
+
+  # The cells contain strings with the following the pattern:
+  # absoluteDifference (percentDifference %). Therefore the background
+  # colors are still wrong. We need to parse the percentage value out
+  # of the string. We do not want to use htmlwidgets::JS() to write our own
+  # rowCallback function (we dont want a dependency on htmlwidgets).
+  # So we modify the existing rowCallback generated by formatStyle
+
+  # extract the rowCallback function
+  old_row <- out[["x"]][["options"]][["rowCallback"]]
+
+  # substitue for each column to get the percentage value
+
+  new_row <- gsub("value=data\\[1\\];", "value; if (data[1] === \"no diff.\")
+                 { value = 0; } else {
+                 value = Math.abs(parseFloat(
+                 data[1].match(/\\\\(([^)]+)\\\\)/)[1].replace('%', '')));}",
+                 old_row)
+  new_row <- gsub("value=data\\[2\\];", "value; if (data[2] === \"no diff.\")
+                 { value = 0; } else {
+                 value = Math.abs(parseFloat(
+                 data[2].match(/\\\\(([^)]+)\\\\)/)[1].replace('%', '')));}",
+                 new_row)
+  new_row <- gsub("value=data\\[3\\];", "value; if (data[3] === \"no diff.\")
+                 { value = 0; } else {
+                 value = Math.abs(parseFloat(
+                 data[3].match(/\\\\(([^)]+)\\\\)/)[1].replace('%', '')));}",
+                 new_row)
+  new_row <- gsub("value=data\\[4\\];", "value; if (data[4] === \"no diff.\")
+                 { value = 0; } else {
+                 value = Math.abs(parseFloat(
+                 data[4].match(/\\\\(([^)]+)\\\\)/)[1].replace('%', '')));}",
+                 new_row)
+
+  #write the modified rowCallback function in the out object
+  out[["x"]][["options"]][["rowCallback"]][1] <- new_row
+
+  return(out)
+}
\ No newline at end of file
