@@ -252,6 +252,11 @@ shiny::shinyServer(function(input, output, session) {
                     tabName = "tab_completeness",
                     icon = icon("chart-line")
                 ),
+                shinydashboard::menuItem(
+                    text = "Difference Checks",
+                    tabName = "tab_differences",
+                    icon = icon("not-equal")
+                ),
                 shinydashboard::menuItem(
                     text = "Reporting",
                     tabName = "tab_report",
@@ -341,6 +346,14 @@ shiny::shinyServer(function(input, output, session) {
                       rv,
                       input_re = input_reactive)
 
+    ########################
+    # tab_differences
+    ########################
+    shiny::callModule(module_differences_server,
+                      "moduleDifferences",
+                      rv,
+                      input_re = input_reactive)
+
     ########################
     # tab_report
     ########################
