@@ -66,6 +66,26 @@ shiny::shinyUI(
           shiny::actionButton(
             inputId = "reset",
             label = "Reset DQA Tool"
+          ),
+          shiny::tags$hr(),
+          shiny::div(
+            class = "sidebar-menu",
+            style = paste0("white-space: normal; text-align:left; ",
+                           "padding: 9.5px 9.5px 9.5px 9.5px; ",
+                           "margin: 6px 10px 6px 10px; ",
+                           "box-sizing:border-box; heigth: auto;",
+                           "width: 230px;"),
+            shiny::HTML(
+              paste0(
+                shiny::tags$a(
+                  "Help / Instructions",
+                  href = paste0(
+                    "https://github.com/miracum/dqa-dqastats/wiki/DQAgui_intro"
+                  ),
+                  target = "_blank"
+                )
+              )
+            )
           )
         ),
         shiny::div(
@@ -121,6 +141,11 @@ shiny::shinyUI(
             module_uniq_plaus_ui("moduleUniquePlausibility")
           ),
 
+          shinydashboard::tabItem(
+            tabName = "tab_differences",
+            module_differences_ui("moduleDifferences")
+          ),
+
           shinydashboard::tabItem(
             tabName = "tab_completeness",
             module_completeness_ui("moduleCompleteness")
